# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DayOfWeekSensor(BaseSensorOperator):
    week_day: "_empty"
    use_task_execution_day: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.operators.python import PythonOperator


class _PythonDecoratedOperator(DecoratedOperator, PythonOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HttpSensor(BaseSensorOperator):
    endpoint: "str"
    http_conn_id: "str"
    method: "str"
    request_params: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    headers: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    response_check: "typing.Union[typing.Callable[..., bool], NoneType]"
    extra_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.sql import (
    SQLCheckOperator,
    SQLIntervalCheckOperator,
    SQLThresholdCheckOperator,
    SQLValueCheckOperator,
)


class CheckOperator(SQLCheckOperator):
    pass


class IntervalCheckOperator(SQLIntervalCheckOperator):
    pass


class ThresholdCheckOperator(SQLThresholdCheckOperator):
    pass


class ValueCheckOperator(SQLValueCheckOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.gcs import (
    GCSListObjectsOperator,
)


class GoogleCloudStorageListOperator(GCSListObjectsOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.operators.sql import (
    SQLCheckOperator,
    SQLIntervalCheckOperator,
    SQLValueCheckOperator,
)


class _BigQueryDbHookMixin:
    pass


class BigQueryCheckOperator(_BigQueryDbHookMixin, SQLCheckOperator):
    sql: "str"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    use_legacy_sql: "bool"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    labels: "typing.Union[dict, NoneType]"


class BigQueryIntervalCheckOperator(_BigQueryDbHookMixin, SQLIntervalCheckOperator):
    table: "str"
    metrics_thresholds: "dict"
    date_filter_column: "str"
    days_back: "typing.SupportsAbs[int]"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    use_legacy_sql: "bool"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"


class BigQueryValueCheckOperator(_BigQueryDbHookMixin, SQLValueCheckOperator):
    sql: "str"
    pass_value: "typing.Any"
    tolerance: "typing.Any"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    use_legacy_sql: "bool"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    labels: "typing.Union[dict, NoneType]"


class BigQueryGetDataOperator(BaseOperator):
    dataset_id: "str"
    table_id: "str"
    max_results: "int"
    selected_fields: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryCreateEmptyDatasetOperator(BaseOperator):
    dataset_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    dataset_reference: "typing.Union[typing.Dict, NoneType]"
    location: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    exists_ok: "bool"


class BigQueryCreateEmptyTableOperator(BaseOperator):
    dataset_id: "str"
    table_id: "str"
    table_resource: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    project_id: "typing.Union[str, NoneType]"
    schema_fields: "typing.Union[typing.List, NoneType]"
    gcs_schema_object: "typing.Union[str, NoneType]"
    time_partitioning: "typing.Union[typing.Dict, NoneType]"
    bigquery_conn_id: "str"
    google_cloud_storage_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    view: "typing.Union[typing.Dict, NoneType]"
    materialized_view: "typing.Union[typing.Dict, NoneType]"
    encryption_configuration: "typing.Union[typing.Dict, NoneType]"
    location: "typing.Union[str, NoneType]"
    cluster_fields: "typing.Union[typing.List[str], NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    exists_ok: "bool"


class BigQueryCreateExternalTableOperator(BaseOperator):
    bucket: "str"
    source_objects: "typing.List"
    destination_project_dataset_table: "str"
    table_resource: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    schema_fields: "typing.Union[typing.List, NoneType]"
    schema_object: "typing.Union[str, NoneType]"
    source_format: "str"
    compression: "str"
    skip_leading_rows: "int"
    field_delimiter: "str"
    max_bad_records: "int"
    quote_character: "typing.Union[str, NoneType]"
    allow_quoted_newlines: "bool"
    allow_jagged_rows: "bool"
    bigquery_conn_id: "str"
    google_cloud_storage_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    src_fmt_configs: "typing.Union[dict, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    encryption_configuration: "typing.Union[typing.Dict, NoneType]"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryDeleteDatasetOperator(BaseOperator):
    dataset_id: "str"
    project_id: "typing.Union[str, NoneType]"
    delete_contents: "bool"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryExecuteQueryOperator(BaseOperator):
    sql: "typing.Union[str, typing.Iterable]"
    destination_dataset_table: "typing.Union[str, NoneType]"
    write_disposition: "str"
    allow_large_results: "typing.Union[bool, NoneType]"
    flatten_results: "typing.Union[bool, NoneType]"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    udf_config: "typing.Union[list, NoneType]"
    use_legacy_sql: "bool"
    maximum_billing_tier: "typing.Union[int, NoneType]"
    maximum_bytes_billed: "typing.Union[float, NoneType]"
    create_disposition: "str"
    schema_update_options: "typing.Union[list, tuple, set, NoneType]"
    query_params: "typing.Union[list, NoneType]"
    labels: "typing.Union[dict, NoneType]"
    priority: "str"
    time_partitioning: "typing.Union[dict, NoneType]"
    api_resource_configs: "typing.Union[dict, NoneType]"
    cluster_fields: "typing.Union[typing.List[str], NoneType]"
    location: "typing.Union[str, NoneType]"
    encryption_configuration: "typing.Union[dict, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryGetDatasetOperator(BaseOperator):
    dataset_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryGetDatasetTablesOperator(BaseOperator):
    dataset_id: "str"
    project_id: "typing.Union[str, NoneType]"
    max_results: "typing.Union[int, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryPatchDatasetOperator(BaseOperator):
    dataset_id: "str"
    dataset_resource: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryUpdateDatasetOperator(BaseOperator):
    dataset_resource: "typing.Dict[str, typing.Any]"
    fields: "typing.Union[typing.List[str], NoneType]"
    dataset_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryUpsertTableOperator(BaseOperator):
    dataset_id: "str"
    table_resource: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class BigQueryDeleteTableOperator(BaseOperator):
    deletion_dataset_table: "str"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    ignore_if_missing: "bool"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudFunctionDeleteFunctionOperator(BaseOperator):
    name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudFunctionDeployFunctionOperator(BaseOperator):
    location: "str"
    body: "typing.Dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    zip_path: "typing.Union[str, NoneType]"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DataflowCreateJavaJobOperator(BaseOperator):
    jar: "str"
    job_name: "str"
    dataflow_default_options: "typing.Union[dict, NoneType]"
    options: "typing.Union[dict, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    location: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    poll_sleep: "int"
    job_class: "typing.Union[str, NoneType]"
    check_if_running: "CheckJobRunning"
    multiple_jobs: "typing.Union[bool, NoneType]"
    cancel_timeout: "typing.Union[int, NoneType]"
    wait_until_finished: "typing.Union[bool, NoneType]"


class DataflowCreatePythonJobOperator(BaseOperator):
    py_file: "str"
    job_name: "str"
    dataflow_default_options: "typing.Union[dict, NoneType]"
    options: "typing.Union[dict, NoneType]"
    py_interpreter: "str"
    py_options: "typing.Union[typing.List[str], NoneType]"
    py_requirements: "typing.Union[typing.List[str], NoneType]"
    py_system_site_packages: "bool"
    project_id: "typing.Union[str, NoneType]"
    location: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    poll_sleep: "int"
    drain_pipeline: "bool"
    cancel_timeout: "typing.Union[int, NoneType]"
    wait_until_finished: "typing.Union[bool, NoneType]"


class DataflowTemplatedJobStartOperator(BaseOperator):
    template: "str"
    job_name: "str"
    options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    dataflow_default_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    parameters: "typing.Union[typing.Dict[str, str], NoneType]"
    project_id: "typing.Union[str, NoneType]"
    location: "str"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    poll_sleep: "int"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    environment: "typing.Union[typing.Dict, NoneType]"
    cancel_timeout: "typing.Union[int, NoneType]"
    wait_until_finished: "typing.Union[bool, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.sql import SqlSensor


class MetastorePartitionSensor(SqlSensor):
    table: "str"
    partition_name: "str"
    schema: "str"
    mysql_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AWSAthenaOperator(BaseOperator):
    query: "str"
    database: "str"
    output_location: "str"
    aws_conn_id: "str"
    client_request_token: "typing.Union[str, NoneType]"
    workgroup: "str"
    query_execution_context: "typing.Union[typing.Dict[str, str], NoneType]"
    result_configuration: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    sleep_time: "int"
    max_tries: "typing.Union[int, NoneType]"



import os
import sys
from contextlib import contextmanager
from types import FunctionType
from typing import Optional, Union

import click
import regex as re
from airfly.utils import qualname


def print_version(ctx, param, value):
    if not value or ctx.resilient_parsing:
        return

    from airfly import __version__

    click.echo(f"Version: {__version__}")

    ctx.exit()


def should_exclude(
    obj: Union[FunctionType, type], pattern: Optional[str] = None, verbose: bool = True
):
    if pattern and isinstance(pattern, str):
        obj_name = qualname(obj)
        if re.search(pattern, obj_name):
            if verbose:
                click.secho("excluding ", err=True, nl=False, fg="bright_white")
                click.secho(obj_name, err=True, fg="bright_black")
            return True

    return False


@contextmanager
def expand_sys_path(*paths: str):

    num = len(paths)

    for p in paths[::-1]:
        if p and isinstance(p, str):

            sys.path.insert(0, p)

    yield

    for _ in range(num):
        sys.path.pop(0)


def validate_includes(ctx, param, value):
    if value:
        for inc in value:
            if not os.path.isfile(inc):
                raise FileNotFoundError(f"Invalid file, got: {inc}")

        return list(value)

    return value


def convert_dag_params(ctx, param, value):

    if not value:
        return (None, None)

    elif isinstance(value, tuple):
        return value

    try:
        pypath, _, varname = value.partition(":")
        return pypath, varname

    except ValueError:
        raise click.BadParameter("format must be '<python-file>:<variable>'")


class InvalidModule(Exception):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DruidOperator(BaseOperator):
    json_index_file: "str"
    druid_ingest_conn_id: "str"
    max_ingestion_time: "typing.Union[int, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.local_to_gcs import (
    LocalFilesystemToGCSOperator,
)


class FileToGoogleCloudStorageOperator(LocalFilesystemToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SegmentTrackEventOperator(BaseOperator):
    user_id: "str"
    event: "str"
    properties: "typing.Union[dict, NoneType]"
    segment_conn_id: "str"
    segment_debug_mode: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.redshift_to_s3 import (
    RedshiftToS3Operator,
)


class RedshiftToS3Transfer(RedshiftToS3Operator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureContainerInstancesOperator(BaseOperator):
    ci_conn_id: "str"
    registry_conn_id: "typing.Union[str, NoneType]"
    resource_group: "str"
    name: "str"
    image: "str"
    region: "str"
    environment_variables: "typing.Union[dict, NoneType]"
    secured_variables: "typing.Union[str, NoneType]"
    volumes: "typing.Union[list, NoneType]"
    memory_in_gb: "typing.Union[typing.Any, NoneType]"
    cpu: "typing.Union[typing.Any, NoneType]"
    gpu: "typing.Union[typing.Any, NoneType]"
    command: "typing.Union[typing.List[str], NoneType]"
    remove_on_error: "bool"
    fail_if_exists: "bool"
    tags: "typing.Union[typing.Dict[str, str], NoneType]"
    os_type: "str"
    restart_policy: "str"
    ip_address: "typing.Union[azure.mgmt.containerinstance.models.ip_address_py3.IpAddress, NoneType]"
    ports: "typing.Union[typing.List[azure.mgmt.containerinstance.models.container_port_py3.ContainerPort], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.docker.operators.docker import DockerOperator


class DockerSwarmOperator(DockerOperator):
    image: "str"
    enable_logging: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.models.skipmixin import SkipMixin


class BaseSQLOperator(BaseOperator):
    conn_id: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"


class SQLCheckOperator(BaseSQLOperator):
    sql: "str"
    conn_id: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"


class SQLIntervalCheckOperator(BaseSQLOperator):
    table: "str"
    metrics_thresholds: "typing.Dict[str, int]"
    date_filter_column: "typing.Union[str, NoneType]"
    days_back: "typing.SupportsAbs[int]"
    ratio_formula: "typing.Union[str, NoneType]"
    ignore_zero: "bool"
    conn_id: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"


class SQLValueCheckOperator(BaseSQLOperator):
    sql: "str"
    pass_value: "typing.Any"
    tolerance: "typing.Any"
    conn_id: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"


class SQLThresholdCheckOperator(BaseSQLOperator):
    sql: "str"
    min_threshold: "typing.Any"
    max_threshold: "typing.Any"
    conn_id: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"


class BranchSQLOperator(BaseSQLOperator, SkipMixin):
    sql: "str"
    follow_task_ids_if_true: "typing.List[str]"
    follow_task_ids_if_false: "typing.List[str]"
    conn_id: "str"
    database: "typing.Union[str, NoneType]"
    parameters: "typing.Union[typing.Mapping, typing.Iterable, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PapermillOperator(BaseOperator):
    input_nb: "typing.Union[str, NoneType]"
    output_nb: "typing.Union[str, NoneType]"
    parameters: "typing.Union[typing.Dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ECSOperator(BaseOperator):
    task_definition: "str"
    cluster: "str"
    overrides: "dict"
    aws_conn_id: "typing.Union[str, NoneType]"
    region_name: "typing.Union[str, NoneType]"
    launch_type: "str"
    capacity_provider_strategy: "typing.Union[list, NoneType]"
    group: "typing.Union[str, NoneType]"
    placement_constraints: "typing.Union[list, NoneType]"
    placement_strategy: "typing.Union[list, NoneType]"
    platform_version: "str"
    network_configuration: "typing.Union[dict, NoneType]"
    tags: "typing.Union[dict, NoneType]"
    awslogs_group: "typing.Union[str, NoneType]"
    awslogs_region: "typing.Union[str, NoneType]"
    awslogs_stream_prefix: "typing.Union[str, NoneType]"
    propagate_tags: "typing.Union[str, NoneType]"
    quota_retry: "typing.Union[dict, NoneType]"
    reattach: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dataflow import (
    DataflowCreateJavaJobOperator,
    DataflowCreatePythonJobOperator,
    DataflowTemplatedJobStartOperator,
)


class DataFlowJavaOperator(DataflowCreateJavaJobOperator):
    pass


class DataFlowPythonOperator(DataflowCreatePythonJobOperator):
    pass


class DataflowTemplateOperator(DataflowTemplatedJobStartOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.mlengine import (
    MLEngineManageModelOperator,
    MLEngineManageVersionOperator,
    MLEngineStartBatchPredictionJobOperator,
    MLEngineStartTrainingJobOperator,
)


class MLEngineBatchPredictionOperator(MLEngineStartBatchPredictionJobOperator):
    pass


class MLEngineModelOperator(MLEngineManageModelOperator):
    pass


class MLEngineTrainingOperator(MLEngineStartTrainingJobOperator):
    pass


class MLEngineVersionOperator(MLEngineManageVersionOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GCSObjectExistenceSensor(BaseSensorOperator):
    bucket: "str"
    object: "str"
    google_cloud_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
    bucket: "str"
    prefix: "str"
    google_cloud_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSObjectUpdateSensor(BaseSensorOperator):
    bucket: "str"
    object: "str"
    ts_func: "typing.Callable"
    google_cloud_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSUploadSessionCompleteSensor(BaseSensorOperator):
    bucket: "str"
    prefix: "str"
    inactivity_period: "float"
    min_objects: "int"
    previous_objects: "typing.Union[typing.Set[str], NoneType]"
    allow_delete: "bool"
    google_cloud_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToHiveOperator(BaseOperator):
    s3_key: "str"
    field_dict: "typing.Dict"
    hive_table: "str"
    delimiter: "str"
    create: "bool"
    recreate: "bool"
    partition: "typing.Union[typing.Dict, NoneType]"
    headers: "bool"
    check_headers: "bool"
    wildcard_match: "bool"
    aws_conn_id: "str"
    verify: "typing.Union[bool, str, NoneType]"
    hive_cli_conn_id: "str"
    input_compressed: "bool"
    tblproperties: "typing.Union[typing.Dict, NoneType]"
    select_expression: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.gcs_to_s3 import (
    GCSToS3Operator,
)


class GoogleCloudStorageToS3Operator(GCSToS3Operator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ComputeEngineBaseOperator(BaseOperator):
    zone: "str"
    resource_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
    resource_id: "str"
    body_patch: "dict"
    project_id: "typing.Union[str, NoneType]"
    request_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(
    ComputeEngineBaseOperator
):
    resource_id: "str"
    zone: "str"
    source_template: "str"
    destination_template: "str"
    project_id: "typing.Union[str, NoneType]"
    update_policy: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    request_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "_empty"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
    zone: "str"
    resource_id: "str"
    body: "dict"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class ComputeEngineStartInstanceOperator(ComputeEngineBaseOperator):
    zone: "str"
    resource_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
    zone: "str"
    resource_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.speech_to_text import (
    CloudSpeechToTextRecognizeSpeechOperator,
)


class GcpSpeechToTextRecognizeSpeechOperator(CloudSpeechToTextRecognizeSpeechOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class MLEngineManageModelOperator(BaseOperator):
    model: "dict"
    operation: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class MLEngineManageVersionOperator(BaseOperator):
    model_name: "str"
    version_name: "typing.Union[str, NoneType]"
    version: "typing.Union[dict, NoneType]"
    operation: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class MLEngineStartBatchPredictionJobOperator(BaseOperator):
    job_id: "str"
    region: "str"
    data_format: "str"
    input_paths: "typing.List[str]"
    output_path: "str"
    model_name: "typing.Union[str, NoneType]"
    version_name: "typing.Union[str, NoneType]"
    uri: "typing.Union[str, NoneType]"
    max_worker_count: "typing.Union[int, NoneType]"
    runtime_version: "typing.Union[str, NoneType]"
    signature_name: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict[str, str], NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class MLEngineStartTrainingJobOperator(BaseOperator):
    job_id: "str"
    region: "str"
    package_uris: "typing.List[str]"
    training_python_module: "str"
    training_args: "typing.List[str]"
    scale_tier: "typing.Union[str, NoneType]"
    master_type: "typing.Union[str, NoneType]"
    master_config: "typing.Union[typing.Dict, NoneType]"
    runtime_version: "typing.Union[str, NoneType]"
    python_version: "typing.Union[str, NoneType]"
    job_dir: "typing.Union[str, NoneType]"
    service_account: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    mode: "str"
    labels: "typing.Union[typing.Dict[str, str], NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CeleryQueueSensor(BaseSensorOperator):
    celery_queue: "str"
    target_task_id: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class ImapAttachmentSensor(BaseSensorOperator):
    attachment_name: "_empty"
    check_regex: "_empty"
    mail_folder: "_empty"
    mail_filter: "_empty"
    conn_id: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
    instance_id: "str"
    database_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class SpannerDeleteInstanceOperator(BaseOperator):
    instance_id: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class SpannerDeployDatabaseInstanceOperator(BaseOperator):
    instance_id: "str"
    database_id: "str"
    ddl_statements: "typing.List[str]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class SpannerDeployInstanceOperator(BaseOperator):
    instance_id: "str"
    configuration_name: "str"
    node_count: "int"
    display_name: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class SpannerQueryDatabaseInstanceOperator(BaseOperator):
    instance_id: "str"
    database_id: "str"
    query: "typing.Union[str, typing.List[str]]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
    instance_id: "str"
    database_id: "str"
    ddl_statements: "typing.List[str]"
    project_id: "typing.Union[str, NoneType]"
    operation_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SnsPublishOperator(BaseOperator):
    target_arn: "str"
    message: "str"
    aws_conn_id: "str"
    subject: "typing.Union[str, NoneType]"
    message_attributes: "typing.Union[dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudTranslateTextOperator(BaseOperator):
    values: "typing.Union[typing.List[str], str]"
    target_language: "str"
    format_: "str"
    source_language: "typing.Union[str, NoneType]"
    model: "str"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmailOperator(BaseOperator):
    to: "typing.Union[typing.List[str], str]"
    subject: "str"
    html_content: "str"
    files: "typing.Union[typing.List, NoneType]"
    cc: "typing.Union[str, typing.List[str], NoneType]"
    bcc: "typing.Union[str, typing.List[str], NoneType]"
    mime_subtype: "str"
    mime_charset: "str"
    conn_id: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CassandraTableSensor(BaseSensorOperator):
    table: "str"
    cassandra_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SSHOperator(BaseOperator):
    ssh_hook: "typing.Union[airflow.providers.ssh.hooks.ssh.SSHHook, NoneType]"
    ssh_conn_id: "typing.Union[str, NoneType]"
    remote_host: "typing.Union[str, NoneType]"
    command: "typing.Union[str, NoneType]"
    timeout: "int"
    environment: "typing.Union[dict, NoneType]"
    get_pty: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SparkSqlOperator(BaseOperator):
    sql: "str"
    conf: "typing.Union[str, NoneType]"
    conn_id: "str"
    total_executor_cores: "typing.Union[int, NoneType]"
    executor_cores: "typing.Union[int, NoneType]"
    executor_memory: "typing.Union[str, NoneType]"
    keytab: "typing.Union[str, NoneType]"
    principal: "typing.Union[str, NoneType]"
    master: "typing.Union[str, NoneType]"
    name: "str"
    num_executors: "typing.Union[int, NoneType]"
    verbose: "bool"
    yarn_queue: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.dummy import DummyOperator
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class ExternalTaskMarker(DummyOperator):
    external_dag_id: "str"
    external_task_id: "str"
    execution_date: "typing.Union[str, datetime.datetime, NoneType]"
    recursion_depth: "int"


class ExternalTaskSensor(BaseSensorOperator):
    external_dag_id: "str"
    external_task_id: "typing.Union[str, NoneType]"
    allowed_states: "typing.Union[typing.Iterable[str], NoneType]"
    failed_states: "typing.Union[typing.Iterable[str], NoneType]"
    execution_delta: "typing.Union[datetime.timedelta, NoneType]"
    execution_date_fn: "typing.Union[typing.Callable, NoneType]"
    check_existence: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.oracle.transfers.oracle_to_oracle import (
    OracleToOracleOperator,
)


class OracleToOracleTransfer(OracleToOracleOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class LocalFilesystemToGCSOperator(BaseOperator):
    src: "_empty"
    dst: "_empty"
    bucket: "_empty"
    gcp_conn_id: "_empty"
    google_cloud_storage_conn_id: "_empty"
    mime_type: "_empty"
    delegate_to: "_empty"
    gzip: "_empty"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3DeleteObjectsOperator(BaseOperator):
    bucket: "str"
    keys: "typing.Union[str, list, NoneType]"
    prefix: "typing.Union[str, NoneType]"
    aws_conn_id: "str"
    verify: "typing.Union[str, bool, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3CopyObjectOperator(BaseOperator):
    source_bucket_key: "str"
    dest_bucket_key: "str"
    source_bucket_name: "typing.Union[str, NoneType]"
    dest_bucket_name: "typing.Union[str, NoneType]"
    source_version_id: "typing.Union[str, NoneType]"
    aws_conn_id: "str"
    verify: "typing.Union[str, bool, NoneType]"
    acl_policy: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DatabricksRunNowOperator(BaseOperator):
    job_id: "typing.Union[str, NoneType]"
    json: "typing.Union[typing.Any, NoneType]"
    notebook_params: "typing.Union[typing.Dict[str, str], NoneType]"
    python_params: "typing.Union[typing.List[str], NoneType]"
    spark_submit_params: "typing.Union[typing.List[str], NoneType]"
    databricks_conn_id: "str"
    polling_period_seconds: "int"
    databricks_retry_limit: "int"
    databricks_retry_delay: "int"
    do_xcom_push: "bool"


class DatabricksSubmitRunOperator(BaseOperator):
    json: "typing.Union[typing.Any, NoneType]"
    spark_jar_task: "typing.Union[typing.Dict[str, str], NoneType]"
    notebook_task: "typing.Union[typing.Dict[str, str], NoneType]"
    spark_python_task: "typing.Union[typing.Dict[str, typing.Union[str, typing.List[str]]], NoneType]"
    spark_submit_task: "typing.Union[typing.Dict[str, typing.List[str]], NoneType]"
    new_cluster: "typing.Union[typing.Dict[str, object], NoneType]"
    existing_cluster_id: "typing.Union[str, NoneType]"
    libraries: "typing.Union[typing.List[typing.Dict[str, str]], NoneType]"
    run_name: "typing.Union[str, NoneType]"
    timeout_seconds: "typing.Union[int, NoneType]"
    databricks_conn_id: "str"
    polling_period_seconds: "int"
    databricks_retry_limit: "int"
    databricks_retry_delay: "int"
    do_xcom_push: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSBucketCreateAclEntryOperator(BaseOperator):
    bucket: "str"
    entity: "str"
    role: "str"
    user_project: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSObjectCreateAclEntryOperator(BaseOperator):
    bucket: "str"
    object_name: "str"
    entity: "str"
    role: "str"
    generation: "typing.Union[int, NoneType]"
    user_project: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSDeleteObjectsOperator(BaseOperator):
    bucket_name: "str"
    objects: "typing.Union[typing.Iterable[str], NoneType]"
    prefix: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSListObjectsOperator(BaseOperator):
    bucket: "str"
    prefix: "typing.Union[str, NoneType]"
    delimiter: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GCSCreateBucketOperator(BaseOperator):
    bucket_name: "str"
    resource: "typing.Union[typing.Dict, NoneType]"
    storage_class: "str"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.s3_list import S3ListOperator


class S3ToGCSOperator(S3ListOperator):
    bucket: "_empty"
    prefix: "_empty"
    delimiter: "_empty"
    aws_conn_id: "_empty"
    verify: "_empty"
    gcp_conn_id: "_empty"
    dest_gcs_conn_id: "_empty"
    dest_gcs: "_empty"
    delegate_to: "_empty"
    replace: "_empty"
    gzip: "_empty"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OracleToAzureDataLakeOperator(BaseOperator):
    filename: "str"
    azure_data_lake_conn_id: "str"
    azure_data_lake_path: "str"
    oracle_conn_id: "str"
    sql: "str"
    sql_params: "typing.Union[dict, NoneType]"
    delimiter: "str"
    encoding: "str"
    quotechar: "str"
    quoting: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BashOperator(BaseOperator):
    bash_command: "str"
    env: "typing.Union[typing.Dict[str, str], NoneType]"
    output_encoding: "str"
    skip_exit_code: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.emr_base import EmrBaseSensor


class EmrStepSensor(EmrBaseSensor):
    job_flow_id: "str"
    step_id: "str"
    target_states: "typing.Union[typing.Iterable[str], NoneType]"
    failed_states: "typing.Union[typing.Iterable[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PostgresOperator(BaseOperator):
    sql: "str"
    postgres_conn_id: "str"
    autocommit: "bool"
    parameters: "typing.Union[typing.Mapping, typing.Iterable, NoneType]"
    database: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SQSPublishOperator(BaseOperator):
    sqs_queue: "str"
    message_content: "str"
    message_attributes: "typing.Union[dict, NoneType]"
    delay_seconds: "int"
    aws_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSerialization:
    pass


class SerializedBaseOperator(BaseOperator, BaseSerialization):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DataprocCreateClusterOperator(BaseOperator):
    cluster_name: "str"
    region: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    cluster_config: "typing.Union[typing.Dict, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    request_id: "typing.Union[str, NoneType]"
    delete_on_error: "bool"
    use_if_exists: "bool"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "float"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class DataprocDeleteClusterOperator(BaseOperator):
    project_id: "str"
    region: "str"
    cluster_name: "str"
    cluster_uuid: "typing.Union[str, NoneType]"
    request_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class DataprocInstantiateInlineWorkflowTemplateOperator(BaseOperator):
    template: "typing.Dict"
    region: "str"
    project_id: "typing.Union[str, NoneType]"
    request_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class DataprocInstantiateWorkflowTemplateOperator(BaseOperator):
    template_id: "str"
    region: "str"
    project_id: "typing.Union[str, NoneType]"
    version: "typing.Union[int, NoneType]"
    request_id: "typing.Union[str, NoneType]"
    parameters: "typing.Union[typing.Dict[str, str], NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class DataprocJobBaseOperator(BaseOperator):
    job_name: "str"
    cluster_name: "str"
    project_id: "typing.Union[str, NoneType]"
    dataproc_properties: "typing.Union[typing.Dict, NoneType]"
    dataproc_jars: "typing.Union[typing.List[str], NoneType]"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    region: "typing.Union[str, NoneType]"
    job_error_states: "typing.Union[typing.Set[str], NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
    asynchronous: "bool"


class DataprocScaleClusterOperator(BaseOperator):
    cluster_name: "str"
    project_id: "typing.Union[str, NoneType]"
    region: "str"
    num_workers: "int"
    num_preemptible_workers: "int"
    graceful_decommission_timeout: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class DataprocSubmitHadoopJobOperator(DataprocJobBaseOperator):
    main_jar: "typing.Union[str, NoneType]"
    main_class: "typing.Union[str, NoneType]"
    arguments: "typing.Union[typing.List, NoneType]"
    archives: "typing.Union[typing.List, NoneType]"
    files: "typing.Union[typing.List, NoneType]"


class DataprocSubmitHiveJobOperator(DataprocJobBaseOperator):
    query: "typing.Union[str, NoneType]"
    query_uri: "typing.Union[str, NoneType]"
    variables: "typing.Union[typing.Dict, NoneType]"


class DataprocSubmitPigJobOperator(DataprocJobBaseOperator):
    query: "typing.Union[str, NoneType]"
    query_uri: "typing.Union[str, NoneType]"
    variables: "typing.Union[typing.Dict, NoneType]"


class DataprocSubmitPySparkJobOperator(DataprocJobBaseOperator):
    main: "str"
    arguments: "typing.Union[typing.List, NoneType]"
    archives: "typing.Union[typing.List, NoneType]"
    pyfiles: "typing.Union[typing.List, NoneType]"
    files: "typing.Union[typing.List, NoneType]"


class DataprocSubmitSparkJobOperator(DataprocJobBaseOperator):
    main_jar: "typing.Union[str, NoneType]"
    main_class: "typing.Union[str, NoneType]"
    arguments: "typing.Union[typing.List, NoneType]"
    archives: "typing.Union[typing.List, NoneType]"
    files: "typing.Union[typing.List, NoneType]"


class DataprocSubmitSparkSqlJobOperator(DataprocJobBaseOperator):
    query: "typing.Union[str, NoneType]"
    query_uri: "typing.Union[str, NoneType]"
    variables: "typing.Union[typing.Dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3FileTransformOperator(BaseOperator):
    source_s3_key: "str"
    dest_s3_key: "str"
    transform_script: "typing.Union[str, NoneType]"
    select_expression: "_empty"
    script_args: "typing.Union[typing.Sequence[str], NoneType]"
    source_aws_conn_id: "str"
    source_verify: "typing.Union[bool, str, NoneType]"
    dest_aws_conn_id: "str"
    dest_verify: "typing.Union[bool, str, NoneType]"
    replace: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.gcs_to_local import (
    GCSToLocalFilesystemOperator,
)


class GoogleCloudStorageDownloadOperator(GCSToLocalFilesystemOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AwsGlueCatalogPartitionSensor(BaseSensorOperator):
    table_name: "str"
    expression: "str"
    aws_conn_id: "str"
    region_name: "typing.Union[str, NoneType]"
    database_name: "str"
    poke_interval: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.models.skipmixin import SkipMixin


class SmartSensorOperator(BaseOperator, SkipMixin):
    poke_interval: "_empty"
    smart_sensor_timeout: "_empty"
    soft_fail: "_empty"
    shard_min: "_empty"
    shard_max: "_empty"
    poke_timeout: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmrTerminateJobFlowOperator(BaseOperator):
    job_flow_id: "str"
    aws_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudSpeechToTextRecognizeSpeechOperator(BaseOperator):
    audio: "RecognitionAudio"
    config: "RecognitionConfig"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.bigquery_to_gcs import (
    BigQueryToGCSOperator,
)


class BigQueryToCloudStorageOperator(BigQueryToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.gcs import (
    GCSBucketCreateAclEntryOperator,
    GCSObjectCreateAclEntryOperator,
)


class GoogleCloudStorageBucketCreateAclEntryOperator(GCSBucketCreateAclEntryOperator):
    pass


class GoogleCloudStorageObjectCreateAclEntryOperator(GCSObjectCreateAclEntryOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
    job_name: "str"
    expected_statuses: "typing.Union[typing.Set[str], str]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AwsBatchOperator(BaseOperator):
    job_name: "str"
    job_definition: "str"
    job_queue: "str"
    overrides: "dict"
    array_properties: "typing.Union[dict, NoneType]"
    parameters: "typing.Union[dict, NoneType]"
    job_id: "typing.Union[str, NoneType]"
    waiters: "typing.Union[typing.Any, NoneType]"
    max_retries: "typing.Union[int, NoneType]"
    status_retries: "typing.Union[int, NoneType]"
    aws_conn_id: "typing.Union[str, NoneType]"
    region_name: "typing.Union[str, NoneType]"
    tags: "typing.Union[dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.translate_speech import (
    CloudTranslateSpeechOperator,
)


class GcpTranslateSpeechOperator(CloudTranslateSpeechOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BashSensor(BaseSensorOperator):
    bash_command: "_empty"
    env: "_empty"
    output_encoding: "_empty"



import ast
import os
from types import FunctionType
from typing import Dict, List, Optional, Sequence, Set, Tuple, Type, Union

import airfly
import regex as re
from airfly._ast import (
    Assign,
    BinOp,
    Call,
    Comment,
    Constant,
    Expr,
    ImportFrom,
    Module,
    Name,
    Pass,
    RShift,
    Store,
    With,
    alias,
    keyword,
    stmt,
    withitem,
)
from airfly._vendor import collect_airflow_operators
from airfly.utils import blacking, isorting, qualname

from .base import BaseTask, TaskTree, Workflow

available_operators = collect_airflow_operators()


class AirflowTask(BaseTask):

    operator_class: Union[Type, str] = "DummyOperator"
    params: Dict[str, Union[FunctionType, str]] = None

    @classmethod
    def _resolve_operator(cls) -> Optional[Type]:

        op = cls.operator_class

        if isinstance(op, str):
            basename = op

        elif isinstance(op, type):
            basename = qualname(op, level=1)

        else:
            return

        items = available_operators[basename]

        if len(items) > 1:
            raise ValueError()  # TODO:

        return items[0]

    @classmethod
    def _resolve_dependency_from_params(
        cls, obj: Union[Dict, List] = None
    ) -> List[Union[FunctionType, Type]]:

        deps = []

        if isinstance(obj, type(None)):

            params = cls.params or {}

            deps.extend(cls._resolve_dependency_from_params(params))

        elif isinstance(obj, str):
            return []

        elif isinstance(obj, (Sequence, Set, Dict)):

            iterator = (
                (el for el in obj)
                if isinstance(obj, (Sequence, Set))
                else (v for _, v in obj.items())
            )

            for el in iterator:
                if isinstance(el, (str, type(None))):
                    continue

                elif isinstance(el, (Sequence, Set, Dict)):  # NOTE: list, tuple, set
                    deps.extend(cls._resolve_dependency_from_params(el))

                elif isinstance(el, FunctionType):
                    deps.append(el)

        return list(set(deps))

    @classmethod
    def collect_dep_stmts(cls) -> List[stmt]:
        """Collect all stmts for all dependencies"""

        param_deps = cls._resolve_dependency_from_params()
        op_dev = cls._resolve_operator()

        op_modname, op_basename = qualname(op_dev).rsplit(".", 1)
        op_modname = op_modname.replace("airfly._vendor.", "")

        dep_stmts = [ImportFrom(module=op_modname, names=[alias(name=op_basename)])]

        for dep in param_deps:
            fn_modname, fn_basename = qualname(dep).rsplit(".", 1)
            dep_stmts.append(
                ImportFrom(module=fn_modname, names=[alias(name=fn_basename)])
            )

        return dep_stmts

    @classmethod
    def to_stmt(cls) -> stmt:

        op = cls._resolve_operator()
        op_name = qualname(op)

        _, op_basename = op_name.rsplit(".", 1)

        task_id = qualname(cls)
        task_varname = task_id.replace(".", "_")

        avai_params = {}
        for base in op.mro()[::-1]:
            avai_params.update(getattr(base, "__annotations__", {}))

        params = dict(task_id=task_id)

        for k, v in (cls.params or {}).items():
            if k in avai_params:
                params.update({k: v})

        assign = Assign(
            targets=[Name(id=task_varname)],
            value=Call(
                func=Name(id=op_basename),
                keywords=[
                    keyword(
                        arg=k,
                        value=(
                            Name(id=qualname(v, level=1))
                            if isinstance(v, FunctionType)
                            else Constant(value=v)  # TODO: handle callable and lambda
                        ),
                    )
                    for k, v in params.items()
                ],
            ),
        )

        return assign


class AirflowDAG(Workflow):

    _default_header = (
        f"This file is auto-generated by {airfly.__name__} {airfly.__version__}"
    )

    def __init__(
        self,
        name: str,
        tasktree: TaskTree,
        includes: Union[str, List[str]] = None,
        dag_params: Tuple[Optional[str], Optional[str]] = None,
    ):

        self._name = name
        self._tasktree = tasktree
        self._includes = includes
        self._dag_params = dag_params

        self._imports = []

    def to_module(self) -> Module:

        body = (
            [self._build_header()]
            + self._build_imports()
            + self._build_includes()
            + [self._build_dag_context()]
        )

        return Module(body=body)

    def render(self, formatted: bool = True) -> str:
        src = re.sub("\n+", "\n", self.to_module().render())

        return isorting(blacking(src)) if formatted else src

    def _build_includes(self) -> List[stmt]:

        if self._includes:
            includes = self._includes
            if isinstance(includes, str):
                includes = [includes]

            imports = []
            statements = []

            for path in includes:
                for st in self._insert_from_pyfile(path):
                    if isinstance(st, (ast.Import, ast.ImportFrom)):
                        if st not in imports:
                            imports.append(st)
                    else:

                        statements.append(st)

            body = (
                imports
                + statements
                + [Comment(body="<" * 10 + " End of code insertion")]
            )

        else:
            body = ast.parse("").body

        return body

    def _build_header(self, header: str = None) -> stmt:
        return Comment(body=header if isinstance(header, str) else self._default_header)

    def _parse_dag_params_from_pyfile(
        self, dag_params: Tuple[Optional[str], Optional[str]]
    ) -> List[keyword]:

        try:
            param_file, param_var = self._dag_params

            if os.path.isfile(param_file):

                with open(param_file) as f:
                    mod = ast.parse(f.read().strip())

                for st in mod.body:
                    if isinstance(st, ast.Assign) and st.targets[0].id == param_var:
                        if isinstance(st.value, ast.Dict) or (
                            isinstance(st.value, ast.Call)
                            and st.value.func.id == "dict"
                        ):

                            return [keyword(arg=None, value=Name(id=param_var))]

        except Exception:
            pass  # TODO: logging

        return []

    def _build_dag_context(self) -> stmt:

        keywords = self._parse_dag_params_from_pyfile(self._dag_params)

        return With(
            items=[
                withitem(
                    context_expr=Call(
                        func=Name(id="DAG"),
                        args=[Constant(value=self._name)],
                        keywords=keywords,
                    ),
                    optional_vars=Name(id="dag", ctx=Store()),
                )
            ],
            body=self._build_dag_body(),
        )

    def _build_dag_body(self) -> List[stmt]:
        body = []

        taskclass: AirflowTask
        for taskclass in sorted(self._tasktree.taskset, key=lambda el: qualname(el)):
            body.append(taskclass.to_stmt())

        for pair in sorted(
            self._tasktree.taskpairs,
            key=lambda el: f"{qualname(el.up)}{qualname(el.down)}",
        ):
            up: AirflowTask = pair.up
            down: AirflowTask = pair.down
            up_stmt: Assign = up.to_stmt()
            down_stmt: Assign = down.to_stmt()
            body.append(
                Expr(
                    value=BinOp(
                        left=Name(id=up_stmt.targets[0]),
                        op=RShift(),
                        right=Name(id=down_stmt.targets[0]),
                    )
                )
            )

        return body if body else [Pass()]

    def _build_imports(self) -> List[stmt]:

        imports = [ImportFrom(module="airflow.models", names=[alias(name="DAG")])]

        taskclass: AirflowTask
        for taskclass in self._tasktree.taskset:
            for st in taskclass.collect_dep_stmts():
                if st not in imports:
                    imports.append(st)

        return imports

    def _insert_from_pyfile(self, path: str) -> List[stmt]:

        try:

            if os.path.isfile(path):

                with open(path) as f:
                    mod = ast.parse(f.read().strip())

                mod.body.insert(0, Comment(body=">" * 10 + f" Include from '{path}'"))

                return mod.body

        except Exception:
            # TODO: logging?
            pass

        return []



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.mssql_to_hive import (
    MsSqlToHiveOperator,
)


class MsSqlToHiveTransfer(MsSqlToHiveOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveStatsCollectionOperator(BaseOperator):
    table: "str"
    partition: "typing.Any"
    extra_exprs: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    excluded_columns: "typing.Union[typing.List[str], NoneType]"
    assignment_func: "typing.Union[typing.Callable[[str, str], typing.Union[typing.Dict[typing.Any, typing.Any], NoneType]], NoneType]"
    metastore_conn_id: "str"
    presto_conn_id: "str"
    mysql_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.sql import SQLCheckOperator, SQLValueCheckOperator
from airfly._vendor.airflow.providers.qubole.operators.qubole import QuboleOperator


class _QuboleCheckOperatorMixin:
    pass


class QuboleCheckOperator(_QuboleCheckOperatorMixin, SQLCheckOperator, QuboleOperator):
    qubole_conn_id: "str"
    results_parser_callable: "typing.Callable"


class QuboleValueCheckOperator(
    _QuboleCheckOperatorMixin, SQLValueCheckOperator, QuboleOperator
):
    pass_value: "typing.Union[str, int, float]"
    tolerance: "typing.Union[int, float, NoneType]"
    results_parser_callable: "typing.Callable"
    qubole_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class PythonSensor(BaseSensorOperator):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.sql import (
    SQLCheckOperator,
    SQLIntervalCheckOperator,
    SQLValueCheckOperator,
)


class PrestoCheckOperator(SQLCheckOperator):
    pass


class PrestoIntervalCheckOperator(SQLIntervalCheckOperator):
    pass


class PrestoValueCheckOperator(SQLValueCheckOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_sql import (
    CloudSQLBaseOperator,
    CloudSQLCreateInstanceDatabaseOperator,
    CloudSQLCreateInstanceOperator,
    CloudSQLDeleteInstanceDatabaseOperator,
    CloudSQLDeleteInstanceOperator,
    CloudSQLExecuteQueryOperator,
    CloudSQLExportInstanceOperator,
    CloudSQLImportInstanceOperator,
    CloudSQLInstancePatchOperator,
    CloudSQLPatchInstanceDatabaseOperator,
)


class CloudSqlBaseOperator(CloudSQLBaseOperator):
    pass


class CloudSqlInstanceCreateOperator(CloudSQLCreateInstanceOperator):
    pass


class CloudSqlInstanceDatabaseCreateOperator(CloudSQLCreateInstanceDatabaseOperator):
    pass


class CloudSqlInstanceDatabaseDeleteOperator(CloudSQLDeleteInstanceDatabaseOperator):
    pass


class CloudSqlInstanceDatabasePatchOperator(CloudSQLPatchInstanceDatabaseOperator):
    pass


class CloudSqlInstanceDeleteOperator(CloudSQLDeleteInstanceOperator):
    pass


class CloudSqlInstanceExportOperator(CloudSQLExportInstanceOperator):
    pass


class CloudSqlInstanceImportOperator(CloudSQLImportInstanceOperator):
    pass


class CloudSqlInstancePatchOperator(CloudSQLInstancePatchOperator):
    pass


class CloudSqlQueryOperator(CloudSQLExecuteQueryOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSQLToGCSOperator(BaseOperator):
    sql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "typing.Union[str, NoneType]"
    approx_max_file_size_bytes: "int"
    export_format: "str"
    field_delimiter: "str"
    null_marker: "typing.Union[str, NoneType]"
    gzip: "bool"
    schema: "typing.Union[str, list, NoneType]"
    parameters: "typing.Union[dict, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleApiToS3Operator(BaseOperator):
    google_api_service_name: "str"
    google_api_service_version: "str"
    google_api_endpoint_path: "str"
    google_api_endpoint_params: "dict"
    s3_destination_key: "str"
    google_api_response_via_xcom: "typing.Union[str, NoneType]"
    google_api_endpoint_params_via_xcom: "typing.Union[str, NoneType]"
    google_api_endpoint_params_via_xcom_task_ids: "typing.Union[str, NoneType]"
    google_api_pagination: "bool"
    google_api_num_retries: "int"
    s3_overwrite: "bool"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    aws_conn_id: "str"
    google_impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.datastore import (
    CloudDatastoreImportEntitiesOperator,
)


class DatastoreImportOperator(CloudDatastoreImportEntitiesOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DynamoDBToS3Operator(BaseOperator):
    dynamodb_table_name: "str"
    s3_bucket_name: "str"
    file_size: "int"
    dynamodb_scan_kwargs: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    s3_key_prefix: "str"
    process_func: "typing.Callable[[typing.Dict[str, typing.Any]], bytes]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class WinRMOperator(BaseOperator):
    winrm_hook: "typing.Union[airflow.providers.microsoft.winrm.hooks.winrm.WinRMHook, NoneType]"
    ssh_conn_id: "typing.Union[str, NoneType]"
    remote_host: "typing.Union[str, NoneType]"
    command: "typing.Union[str, NoneType]"
    ps_path: "typing.Union[str, NoneType]"
    output_encoding: "str"
    timeout: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.adls_to_gcs import (
    ADLSToGCSOperator,
)


class AdlsToGoogleCloudStorageOperator(ADLSToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.gcs_to_bigquery import (
    GCSToBigQueryOperator,
)


class GoogleCloudStorageToBigQueryOperator(GCSToBigQueryOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToLocalFilesystemOperator(BaseOperator):
    bucket: "str"
    object_name: "typing.Union[str, NoneType]"
    filename: "typing.Union[str, NoneType]"
    store_to_xcom_key: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_storage_transfer_service import (
    CloudDataTransferServiceCancelOperationOperator,
    CloudDataTransferServiceCreateJobOperator,
    CloudDataTransferServiceDeleteJobOperator,
    CloudDataTransferServiceGCSToGCSOperator,
    CloudDataTransferServiceGetOperationOperator,
    CloudDataTransferServiceListOperationsOperator,
    CloudDataTransferServicePauseOperationOperator,
    CloudDataTransferServiceResumeOperationOperator,
    CloudDataTransferServiceS3ToGCSOperator,
    CloudDataTransferServiceUpdateJobOperator,
)


class GcpTransferServiceJobCreateOperator(CloudDataTransferServiceCreateJobOperator):
    pass


class GcpTransferServiceJobDeleteOperator(CloudDataTransferServiceDeleteJobOperator):
    pass


class GcpTransferServiceJobUpdateOperator(CloudDataTransferServiceUpdateJobOperator):
    pass


class GcpTransferServiceOperationCancelOperator(
    CloudDataTransferServiceCancelOperationOperator
):
    pass


class GcpTransferServiceOperationGetOperator(
    CloudDataTransferServiceGetOperationOperator
):
    pass


class GcpTransferServiceOperationPauseOperator(
    CloudDataTransferServicePauseOperationOperator
):
    pass


class GcpTransferServiceOperationResumeOperator(
    CloudDataTransferServiceResumeOperationOperator
):
    pass


class GcpTransferServiceOperationsListOperator(
    CloudDataTransferServiceListOperationsOperator
):
    pass


class GoogleCloudStorageToGoogleCloudStorageTransferOperator(
    CloudDataTransferServiceGCSToGCSOperator
):
    pass


class S3ToGoogleCloudStorageTransferOperator(CloudDataTransferServiceS3ToGCSOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveToSambaOperator(BaseOperator):
    hql: "str"
    destination_filepath: "str"
    samba_conn_id: "str"
    hiveserver2_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SqlSensor(BaseSensorOperator):
    conn_id: "_empty"
    sql: "_empty"
    parameters: "_empty"
    success: "_empty"
    failure: "_empty"
    fail_on_empty: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.branch import BaseBranchOperator


class LatestOnlyOperator(BaseBranchOperator):
    task_id: "str"
    owner: "str"
    email: "typing.Union[str, typing.Iterable[str], NoneType]"
    email_on_retry: "bool"
    email_on_failure: "bool"
    retries: "typing.Union[int, NoneType]"
    retry_delay: "timedelta"
    retry_exponential_backoff: "bool"
    max_retry_delay: "typing.Union[datetime.timedelta, NoneType]"
    start_date: "typing.Union[datetime.datetime, NoneType]"
    end_date: "typing.Union[datetime.datetime, NoneType]"
    depends_on_past: "bool"
    wait_for_downstream: "bool"
    dag: "_empty"
    params: "typing.Union[typing.Dict, NoneType]"
    default_args: "typing.Union[typing.Dict, NoneType]"
    priority_weight: "int"
    weight_rule: "str"
    queue: "str"
    pool: "typing.Union[str, NoneType]"
    pool_slots: "int"
    sla: "typing.Union[datetime.timedelta, NoneType]"
    execution_timeout: "typing.Union[datetime.timedelta, NoneType]"
    on_execute_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    on_failure_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    on_success_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    on_retry_callback: "typing.Union[typing.Callable[[typing.Dict[str, typing.Any]], NoneType], NoneType]"
    trigger_rule: "str"
    resources: "typing.Union[typing.Dict, NoneType]"
    run_as_user: "typing.Union[str, NoneType]"
    task_concurrency: "typing.Union[int, NoneType]"
    executor_config: "typing.Union[typing.Dict, NoneType]"
    do_xcom_push: "bool"
    inlets: "typing.Union[typing.Any, NoneType]"
    outlets: "typing.Union[typing.Any, NoneType]"
    task_group: "typing.Union[ForwardRef('TaskGroup'), NoneType]"
    doc: "typing.Union[str, NoneType]"
    doc_md: "typing.Union[str, NoneType]"
    doc_json: "typing.Union[str, NoneType]"
    doc_yaml: "typing.Union[str, NoneType]"
    doc_rst: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.mysql.transfers.vertica_to_mysql import (
    VerticaToMySqlOperator,
)


class VerticaToMySqlTransfer(VerticaToMySqlOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.mysql_to_hive import (
    MySqlToHiveOperator,
)


class MySqlToHiveTransfer(MySqlToHiveOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToGoogleDriveOperator(BaseOperator):
    source_bucket: "str"
    source_object: "str"
    destination_object: "typing.Union[str, NoneType]"
    move_object: "bool"
    gcp_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudVisionAddProductToProductSetOperator(BaseOperator):
    product_set_id: "str"
    product_id: "str"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionCreateProductOperator(BaseOperator):
    location: "str"
    product: "str"
    project_id: "typing.Union[str, NoneType]"
    product_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionCreateProductSetOperator(BaseOperator):
    product_set: "typing.Union[dict, google.cloud.vision_v1.types.ProductSet]"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    product_set_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionCreateReferenceImageOperator(BaseOperator):
    location: "str"
    reference_image: "typing.Union[typing.Dict, google.cloud.vision_v1.types.ReferenceImage]"
    product_id: "str"
    reference_image_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionDeleteProductOperator(BaseOperator):
    location: "str"
    product_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionDeleteProductSetOperator(BaseOperator):
    location: "str"
    product_set_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionDetectImageLabelsOperator(BaseOperator):
    image: "typing.Union[typing.Dict, google.cloud.vision_v1.types.Image]"
    max_results: "typing.Union[int, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    additional_properties: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
    image: "typing.Union[typing.Dict, google.cloud.vision_v1.types.Image]"
    max_results: "typing.Union[int, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    additional_properties: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionDetectTextOperator(BaseOperator):
    image: "typing.Union[typing.Dict, google.cloud.vision_v1.types.Image]"
    max_results: "typing.Union[int, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    language_hints: "typing.Union[str, typing.List[str], NoneType]"
    web_detection_params: "typing.Union[typing.Dict, NoneType]"
    additional_properties: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionGetProductOperator(BaseOperator):
    location: "str"
    product_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionGetProductSetOperator(BaseOperator):
    location: "str"
    product_set_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionImageAnnotateOperator(BaseOperator):
    request: "typing.Union[typing.Dict, google.cloud.vision_v1.types.AnnotateImageRequest]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
    product_set_id: "str"
    product_id: "str"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionTextDetectOperator(BaseOperator):
    image: "typing.Union[typing.Dict, google.cloud.vision_v1.types.Image]"
    max_results: "typing.Union[int, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    language_hints: "typing.Union[str, typing.List[str], NoneType]"
    web_detection_params: "typing.Union[typing.Dict, NoneType]"
    additional_properties: "typing.Union[typing.Dict, NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionUpdateProductOperator(BaseOperator):
    product: "typing.Union[typing.Dict, google.cloud.vision_v1.types.Product]"
    location: "typing.Union[str, NoneType]"
    product_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudVisionUpdateProductSetOperator(BaseOperator):
    product_set: "typing.Union[typing.Dict, google.cloud.vision_v1.types.ProductSet]"
    location: "typing.Union[str, NoneType]"
    product_set_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class S3ToRedshiftOperator(BaseOperator):
    schema: "str"
    table: "str"
    s3_bucket: "str"
    s3_key: "str"
    redshift_conn_id: "str"
    aws_conn_id: "str"
    verify: "typing.Union[bool, str, NoneType]"
    column_list: "typing.Union[typing.List[str], NoneType]"
    copy_options: "typing.Union[typing.List, NoneType]"
    autocommit: "bool"
    truncate_table: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.http.operators.http import SimpleHttpOperator


class DiscordWebhookOperator(SimpleHttpOperator):
    http_conn_id: "typing.Union[str, NoneType]"
    webhook_endpoint: "typing.Union[str, NoneType]"
    message: "str"
    username: "typing.Union[str, NoneType]"
    avatar_url: "typing.Union[str, NoneType]"
    tts: "bool"
    proxy: "typing.Union[str, NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudDLPCancelDLPJobOperator(BaseOperator):
    dlp_job_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPCreateDeidentifyTemplateOperator(BaseOperator):
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    deidentify_template: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.DeidentifyTemplate, NoneType]"
    template_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPCreateDLPJobOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    inspect_job: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectJobConfig, NoneType]"
    risk_job: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.RiskAnalysisJobConfig, NoneType]"
    job_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    wait_until_finished: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPCreateInspectTemplateOperator(BaseOperator):
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    inspect_template: "typing.Union[google.cloud.dlp_v2.types.InspectTemplate, NoneType]"
    template_id: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectTemplate, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPCreateJobTriggerOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    job_trigger: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.JobTrigger, NoneType]"
    trigger_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPCreateStoredInfoTypeOperator(BaseOperator):
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    config: "typing.Union[google.cloud.dlp_v2.types.StoredInfoTypeConfig, NoneType]"
    stored_info_type_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPDeidentifyContentOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    deidentify_config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.DeidentifyConfig, NoneType]"
    inspect_config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectConfig, NoneType]"
    item: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.ContentItem, NoneType]"
    inspect_template_name: "typing.Union[str, NoneType]"
    deidentify_template_name: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPDeleteDeidentifyTemplateOperator(BaseOperator):
    template_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPDeleteDLPJobOperator(BaseOperator):
    dlp_job_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPDeleteInspectTemplateOperator(BaseOperator):
    template_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPDeleteJobTriggerOperator(BaseOperator):
    job_trigger_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPDeleteStoredInfoTypeOperator(BaseOperator):
    stored_info_type_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPGetDeidentifyTemplateOperator(BaseOperator):
    template_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPGetDLPJobOperator(BaseOperator):
    dlp_job_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPGetDLPJobTriggerOperator(BaseOperator):
    job_trigger_id: "str"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPGetInspectTemplateOperator(BaseOperator):
    template_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPGetStoredInfoTypeOperator(BaseOperator):
    stored_info_type_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPInspectContentOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    inspect_config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectConfig, NoneType]"
    item: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.ContentItem, NoneType]"
    inspect_template_name: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPListDeidentifyTemplatesOperator(BaseOperator):
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    page_size: "typing.Union[int, NoneType]"
    order_by: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPListDLPJobsOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    results_filter: "typing.Union[str, NoneType]"
    page_size: "typing.Union[int, NoneType]"
    job_type: "typing.Union[str, NoneType]"
    order_by: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPListInfoTypesOperator(BaseOperator):
    language_code: "typing.Union[str, NoneType]"
    results_filter: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPListInspectTemplatesOperator(BaseOperator):
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    page_size: "typing.Union[int, NoneType]"
    order_by: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPListJobTriggersOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    page_size: "typing.Union[int, NoneType]"
    order_by: "typing.Union[str, NoneType]"
    results_filter: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPListStoredInfoTypesOperator(BaseOperator):
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    page_size: "typing.Union[int, NoneType]"
    order_by: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPRedactImageOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    inspect_config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectConfig, NoneType]"
    image_redaction_configs: "typing.Union[typing.Dict, google.cloud.dlp_v2.proto.dlp_pb2.ImageRedactionConfig, NoneType]"
    include_findings: "typing.Union[bool, NoneType]"
    byte_item: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.ByteContentItem, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPReidentifyContentOperator(BaseOperator):
    project_id: "typing.Union[str, NoneType]"
    reidentify_config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.DeidentifyConfig, NoneType]"
    inspect_config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectConfig, NoneType]"
    item: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.ContentItem, NoneType]"
    inspect_template_name: "typing.Union[str, NoneType]"
    reidentify_template_name: "typing.Union[str, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPUpdateDeidentifyTemplateOperator(BaseOperator):
    template_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    deidentify_template: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.DeidentifyTemplate, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPUpdateInspectTemplateOperator(BaseOperator):
    template_id: "str"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    inspect_template: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.InspectTemplate, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPUpdateJobTriggerOperator(BaseOperator):
    job_trigger_id: "_empty"
    project_id: "typing.Union[str, NoneType]"
    job_trigger: "typing.Union[google.cloud.dlp_v2.types.JobTrigger, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDLPUpdateStoredInfoTypeOperator(BaseOperator):
    stored_info_type_id: "_empty"
    organization_id: "typing.Union[str, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    config: "typing.Union[typing.Dict, google.cloud.dlp_v2.types.StoredInfoTypeConfig, NoneType]"
    update_mask: "typing.Union[typing.Dict, google.protobuf.field_mask_pb2.FieldMask, NoneType]"
    retry: "typing.Union[google.api_core.retry.Retry, NoneType]"
    timeout: "typing.Union[float, NoneType]"
    metadata: "typing.Union[typing.Sequence[typing.Tuple[str, str]], NoneType]"
    gcp_conn_id: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CloudDatastoreExportEntitiesOperator(BaseOperator):
    bucket: "str"
    namespace: "typing.Union[str, NoneType]"
    datastore_conn_id: "str"
    cloud_storage_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    entity_filter: "typing.Union[dict, NoneType]"
    labels: "typing.Union[dict, NoneType]"
    polling_interval_in_seconds: "int"
    overwrite_existing: "bool"
    project_id: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class CloudDatastoreImportEntitiesOperator(BaseOperator):
    bucket: "str"
    file: "str"
    namespace: "typing.Union[str, NoneType]"
    entity_filter: "typing.Union[dict, NoneType]"
    labels: "typing.Union[dict, NoneType]"
    datastore_conn_id: "str"
    delegate_to: "typing.Union[str, NoneType]"
    polling_interval_in_seconds: "float"
    project_id: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.pubsub import (
    PubSubCreateSubscriptionOperator,
    PubSubCreateTopicOperator,
    PubSubDeleteSubscriptionOperator,
    PubSubDeleteTopicOperator,
    PubSubPublishMessageOperator,
)


class PubSubPublishOperator(PubSubPublishMessageOperator):
    pass


class PubSubSubscriptionCreateOperator(PubSubCreateSubscriptionOperator):
    pass


class PubSubSubscriptionDeleteOperator(PubSubDeleteSubscriptionOperator):
    pass


class PubSubTopicCreateOperator(PubSubCreateTopicOperator):
    pass


class PubSubTopicDeleteOperator(PubSubDeleteTopicOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.kubernetes_engine import (
    GKECreateClusterOperator,
    GKEDeleteClusterOperator,
    GKEStartPodOperator,
)


class GKEClusterCreateOperator(GKECreateClusterOperator):
    pass


class GKEClusterDeleteOperator(GKEDeleteClusterOperator):
    pass


class GKEPodOperator(GKEStartPodOperator):
    pass
